class TokenError(Exception):
    pass

_api_key = None

def login(api_key):
    global _api_key
    if not api_key:
        raise TokenError("API key is empty. Please provide a valid API key.")
    _api_key = api_key

def get_api_key():
    if not _api_key:
        raise TokenError("API key not set. Please call login() first.")
    return _api_key



from .token import login
from .voice_models.fetch_voice_models import fetch_voice_models
from .voice_models.fetch_voice_model_by_id import fetch_voice_model_by_id

from .voice_conversions.create_voice_conversion import create_voice_conversion
from .voice_conversions.fetch_voice_conversion_by_id import fetch_voice_conversion_by_id
from .voice_conversions.fetch_voice_conversions import fetch_voice_conversions

from .vocal_separations.create_vocal_separation import create_vocal_separation
from .vocal_separations.fetch_vocal_separation_by_id import fetch_vocal_separation_by_id
from .vocal_separations.fetch_vocal_separations import fetch_vocal_separations

from .tts.create_tts import create_tts
from .tts.fetch_tts_by_id import fetch_tts_by_id
from .tts.fetch_tts import fetch_tts


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

setup(
    name="kitsai",
    version="0.0.2",
    author="Blaise",
    author_email="iahispano0@gmail.com",
    description="Unofficial package to easily interact with the Kits.AI API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="Attribution-NonCommercial 4.0 International",
    packages=find_packages(),
    url="https://github.com/blaise-tk/kitsai",
    keywords=["python", "audio", "vc", "ai", "rvc", "kits"],
    classifiers=[
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows :: Windows 10",
        "Operating System :: POSIX :: Linux",
    ],
)
